summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldermbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldermbox.h')
-rw-r--r--kmail/kmfoldermbox.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kmail/kmfoldermbox.h b/kmail/kmfoldermbox.h
index cf887137..d3741144 100644
--- a/kmail/kmfoldermbox.h
+++ b/kmail/kmfoldermbox.h
@@ -52,8 +52,8 @@ class KMFolderMbox : public KMFolderIndex
public:
- /** Usually a tqparent is given. But in some cases there is no
- fitting tqparent object available. Then the name of the folder
+ /** Usually a parent is given. But in some cases there is no
+ fitting parent object available. Then the name of the folder
is used as the absolute path to the folder file. */
KMFolderMbox(KMFolder* folder, const char* name=0);
virtual ~KMFolderMbox();